/*
 * Java Othello Openings Applet
 * Copyright (C) 2000 Bill Lorton
 * email: hogarth1@yahoo.com
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/**
 *
 * An object that contains an opening's data.
 *
 * @version 1.00
 * @author Bill Lorton
 *
 */
class Opening extends Object {
  private String _name;
  private String _moves;
  private int    _frequency;
  private double _frequency_percent;


  /**
   *
   * The Opening constructor.
   *
   */
  public Opening()
  {
    _name = "";
    _moves = "";
    _frequency = 0;
    _frequency_percent = 0.0;
  }


  /**
   *
   * Sets the name of this opening.
   *
   * @param name the name of this opening
   */
  public void setName(String name) { _name = name; }


  /**
   *
   * Sets the complete move sequence of this opening.
   *
   * @param moves the moves of this opening
   *
   */
  public void setMoves(String moves) { _moves = moves; }


  /**
   *
   * Sets the frequency of this opening.
   *
   * @param count the frequency of this opening
   *
   */
  public void setFrequency(int count) { _frequency = count;}


  /**
   *
   * Sets the frequency precentage of this opening
   *
   * @param percent the frequency percentage of this opening
   *
   */
  public void setFrequencyPercent(double percent) 
  {
    _frequency_percent = percent; 
  }


  /**
   *
   * Gets the name of this opening.
   *
   * @return the name of this opening
   *
   */
  public String name() { return _name; }


  /**
   *
   * Gets the complete move string of this opening.
   *
   * @return the move string of this opening
   *
   */
  public String moves() { return _moves; }


  /**
   *
   * Gets the frequency of this opening.
   *
   * @return the frequency of this opening
   *
   */
  public int frequency() { return _frequency; }


  /**
   *
   * Gets the frequency percentage of this opening.
   *
   * @return the frequency percentage of this opening
   *
   */
  public double frequencyPercent() { return _frequency_percent; }
};

